@@ -121,8 +121,9 @@ if TYPE_CHECKING:
         total=False,
     )
 
-    ExcInfo = Tuple[
-        Optional[Type[BaseException]], Optional[BaseException], Optional[TracebackType]
+    ExcInfo = Union[
+        tuple[Type[BaseException], BaseException, Optional[TracebackType]],
+        tuple[None, None, None],
     ]
 
     Hint = Dict[str, Any]
